/**********************************************************************************************
    Copyright (C) 2014 Oliver Eichler <oliver.eichler@gmx.de>

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.

**********************************************************************************************/

#ifndef CQLGTDIARY_H
#define CQLGTDIARY_H

#include <QObject>

#include "qlgt/IItem.h"

class CQlgtDiary : public QObject, public IItem {
 public:
  CQlgtDiary(quint64 id, QObject* parent);
  virtual ~CQlgtDiary();

  enum type_e { eEnd, eBase, eWpt, eTrk, eRte };

  quint64 keyProjectGeoDB = 0;
};

QDataStream& operator>>(QDataStream& s, CQlgtDiary& diary);
QDataStream& operator<<(QDataStream& s, CQlgtDiary& diary);

#endif  // CQLGTDIARY_H
